Credentials class

Constructors

Credentials({required String consumerKey, required String consumerSecret, required String token, required String tokenSecret})

Properties

consumerKey String
final
consumerSecret String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final
tokenSecret String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited