OAuthHandler class

Constructors

OAuthHandler({required Credentials credentials, int maxRetries = 3, Duration timeout = const Duration(seconds: 30)})

Properties

credentials Credentials
final
hashCode int
The hash code for this object.
no setterinherited
maxRetries int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final

Methods

logRequest(Request request) → void
logResponse(Response response) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendRequest(String url, Map<String, String> params, {String method = 'GET', dynamic body}) Future<Response>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited